Learn R Programming

apaStyle (version 0.3)

apa.signif: Generic method to make a footnote indicating significant values.

Description

Generic method to make a footnote indicating significant values.

Usage

apa.signif(data = data.frame())

Arguments

data
Dataset with statistics.

Value

apa.signif object; a list consisting of
succes
message in case of an error
signif
pot {ReporteRs} object

Examples

Run this code
# Specify statistics
example <- data.frame(
  c("Column 1", "Column 2", "Column 3"),
  c(3.45, 5.21, 2.64),
  c("**", "", "***")
)

# Use apa.descriptives function
apa.signif(data = example)

Run the code above in your browser using DataLab