Learn R Programming

apaStyle (version 0.3)

apa.merge: Generic method to merge two vectors and create a header

Description

Generic method to merge two vectors and create a header

Usage

apa.merge(a = NULL, b = NULL, header = NULL)

Arguments

a
Values in the first column.
b
Values in the second column.
header
Vector with both column names.

Value

apa.merge object; a list consisting of
succes
message in case of an error
data
the merged data
header
the header for the merged data

Examples

Run this code
# Use apa.merge function
apa.merge(a = rnorm(100, mean = 0, sd = 1), b = rnorm(100, mean = 0, sd = 1), header = c("M", "SD"))

Run the code above in your browser using DataLab